% SVD analysis of Senate/House of Representatives roll call
% Jesse Chan, 4/15/2018
% 
% see also: https://people.maths.ox.ac.uk/porterm/papers/s4.pdf

!python getCongress.py s114.ord

fid = fopen('names.txt');
names = textscan(fid, '%25s','Delimiter','\t');
fclose(fid);
names = names{1};
load parties.txt;
load votes.txt;
votes = votes';
% for i = 1:size(votes,2)
%     votes(:,i) = votes(:,i)-mean(votes(:,i));
% end

dems = find(parties==100);
reps = find(parties==200);

[U S V] = svd(votes,'econ');
Uk = U(:,1:2);
Sk = S(1:2,1:2);
Vk = V(:,1:2);
% c = Uk'*votes;
% c = Sk*Vk';
c = Vk';
% c(1,:) = c(1,:)/min(abs(c(1,:)));
% c(2,:) = c(2,:)/min(abs(c(2,:)));
% c = (Uk*Sk)'*votes; 

% ===================================================================

off = mean(c(:))*.075; % offset

% for p = 1:size(c,2)
p = find(abs(c(1,:))<.1);
p = 1:size(c,2);

figure
plot(c(1,reps),c(2,reps),'r.','markersize',12)
hold on;
plot(c(1,dems),c(2,dems),'b.','markersize',12)
ylabel('c_2: tendency to vote with majority','fontsize',15)
xlabel('c_1: tendency to vote with party','fontsize',15)
set(gca,'fontsize',14)
plot(c(1,p),c(2,p),'ks')
text(c(1,p) + off,c(2,p) + off,names(p))

%% predictability

figure
approx_votes = Uk*Sk*Vk';
% assign approximate votes by sign
approx_votes(approx_votes<0) = -1; 
approx_votes(approx_votes>0) = 1;
approx_votes(votes==0) = 0; % ignore abstensions

predictable = sum((votes==approx_votes),1)/size(votes,1);
plot(c(1,reps),predictable(reps),'r.','markersize',12)
hold on
plot(c(1,dems),predictable(dems),'b.','markersize',12)
text(c(1,:),predictable + .001,names)



